package
Version:
v0.0.0-...-0d0b2b3
Opens a new window with list of versions in this module.
Published: Aug 20, 2024
License: MIT
Opens a new window with license information.
Imports: 13
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
Server serves http request to out banking serivce
Newserver create new http server and creates routes
starts server on a specific address
type UserResponse struct {
Username string `json:"username"`
FullName string `json:"full_name"`
Email string `json:"email"`
PasswordChangedAt time.Time `json:"password_changed_at"`
CreatedAt time.Time `json:"created_at"`
}
Source Files
¶
Click to show internal directories.
Click to hide internal directories.